/* A Bison parser, made by GNU Bison 2.7.12-4996.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_DVDVM_DVDVMY_H_INCLUDED
# define YY_DVDVM_DVDVMY_H_INCLUDED
/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int dvdvmdebug;
#endif

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NUM_TOK = 258,
     G_TOK = 259,
     S_TOK = 260,
     ID_TOK = 261,
     ANGLE_TOK = 262,
     AUDIO_TOK = 263,
     BREAK_TOK = 264,
     BUTTON_TOK = 265,
     CALL_TOK = 266,
     CELL_TOK = 267,
     CHAPTER_TOK = 268,
     CLOSEBRACE_TOK = 269,
     CLOSEPAREN_TOK = 270,
     COUNTER_TOK = 271,
     ELSE_TOK = 272,
     ENTRY_TOK = 273,
     EXIT_TOK = 274,
     FPC_TOK = 275,
     GOTO_TOK = 276,
     IF_TOK = 277,
     JUMP_TOK = 278,
     LAST_TOK = 279,
     MENU_TOK = 280,
     NEXT_TOK = 281,
     OPENBRACE_TOK = 282,
     OPENPAREN_TOK = 283,
     PGC_TOK = 284,
     PREV_TOK = 285,
     PROGRAM_TOK = 286,
     PTT_TOK = 287,
     REGION_TOK = 288,
     RESUME_TOK = 289,
     RND_TOK = 290,
     ROOT_TOK = 291,
     SET_TOK = 292,
     SUBTITLE_TOK = 293,
     TAIL_TOK = 294,
     TITLE_TOK = 295,
     TITLESET_TOK = 296,
     TOP_TOK = 297,
     UP_TOK = 298,
     VMGM_TOK = 299,
     BOR_TOK = 300,
     LOR_TOK = 301,
     XOR_TOK = 302,
     _OR_TOK = 303,
     BAND_TOK = 304,
     LAND_TOK = 305,
     _AND_TOK = 306,
     NOT_TOK = 307,
     NE_TOK = 308,
     EQ_TOK = 309,
     LT_TOK = 310,
     LE_TOK = 311,
     GT_TOK = 312,
     GE_TOK = 313,
     SUB_TOK = 314,
     ADD_TOK = 315,
     MOD_TOK = 316,
     DIV_TOK = 317,
     MUL_TOK = 318,
     ADDSET_TOK = 319,
     SUBSET_TOK = 320,
     MULSET_TOK = 321,
     DIVSET_TOK = 322,
     MODSET_TOK = 323,
     ANDSET_TOK = 324,
     ORSET_TOK = 325,
     XORSET_TOK = 326,
     SEMICOLON_TOK = 327,
     COLON_TOK = 328,
     ERROR_TOK = 329
   };
#endif
/* Tokens.  */
#define NUM_TOK 258
#define G_TOK 259
#define S_TOK 260
#define ID_TOK 261
#define ANGLE_TOK 262
#define AUDIO_TOK 263
#define BREAK_TOK 264
#define BUTTON_TOK 265
#define CALL_TOK 266
#define CELL_TOK 267
#define CHAPTER_TOK 268
#define CLOSEBRACE_TOK 269
#define CLOSEPAREN_TOK 270
#define COUNTER_TOK 271
#define ELSE_TOK 272
#define ENTRY_TOK 273
#define EXIT_TOK 274
#define FPC_TOK 275
#define GOTO_TOK 276
#define IF_TOK 277
#define JUMP_TOK 278
#define LAST_TOK 279
#define MENU_TOK 280
#define NEXT_TOK 281
#define OPENBRACE_TOK 282
#define OPENPAREN_TOK 283
#define PGC_TOK 284
#define PREV_TOK 285
#define PROGRAM_TOK 286
#define PTT_TOK 287
#define REGION_TOK 288
#define RESUME_TOK 289
#define RND_TOK 290
#define ROOT_TOK 291
#define SET_TOK 292
#define SUBTITLE_TOK 293
#define TAIL_TOK 294
#define TITLE_TOK 295
#define TITLESET_TOK 296
#define TOP_TOK 297
#define UP_TOK 298
#define VMGM_TOK 299
#define BOR_TOK 300
#define LOR_TOK 301
#define XOR_TOK 302
#define _OR_TOK 303
#define BAND_TOK 304
#define LAND_TOK 305
#define _AND_TOK 306
#define NOT_TOK 307
#define NE_TOK 308
#define EQ_TOK 309
#define LT_TOK 310
#define LE_TOK 311
#define GT_TOK 312
#define GE_TOK 313
#define SUB_TOK 314
#define ADD_TOK 315
#define MOD_TOK 316
#define DIV_TOK 317
#define MUL_TOK 318
#define ADDSET_TOK 319
#define SUBSET_TOK 320
#define MULSET_TOK 321
#define DIVSET_TOK 322
#define MODSET_TOK 323
#define ANDSET_TOK 324
#define ORSET_TOK 325
#define XORSET_TOK 326
#define SEMICOLON_TOK 327
#define COLON_TOK 328
#define ERROR_TOK 329



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{
/* Line 2053 of yacc.c  */
#line 92 "dvdvmy.y"

    unsigned int int_val;
    char *str_val;
    struct vm_statement *statement;


/* Line 2053 of yacc.c  */
#line 212 "dvdvmy.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE dvdvmlval;

#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int dvdvmparse (void *YYPARSE_PARAM);
#else
int dvdvmparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int dvdvmparse (void);
#else
int dvdvmparse ();
#endif
#endif /* ! YYPARSE_PARAM */

#endif /* !YY_DVDVM_DVDVMY_H_INCLUDED  */
